#
# spec file for package nudoku
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nudoku
Version:        5.0.0
Release:        1.5
Summary:        Ncurses based sudoku game
License:        GPL-3.0-only
Group:          Amusements/Games/Board/Puzzle
URL:            https://github.com/jubalh/%{name}
Source:         https://github.com/jubalh/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cairo-devel
BuildRequires:  ncurses-devel
BuildRequires:  xz
Recommends:     %{name}-lang

%description
nudoku is a ncurses based sudoku game.

%lang_package

%prep
%setup -q

%build
autoreconf -fi
%configure --enable-cairo
%make_build

%install
%make_install

%find_lang %{name}

%files
%{_bindir}/nudoku
%{_mandir}/man?/nudoku.*

%files lang -f %{name}.lang
%{_datadir}/locale/??/LC_MESSAGES/nudoku.mo

%changelog
* Tue Aug 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 5.0.0:
  * Add Ukrainian translation (pr #62)
  * Don't create ambiguous games (#50, pr #63)
  * Allow to pause game (#47, pr #65)
* Mon May  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 4.0.1:
  * Add macOS CI (pr #60)
  * Fix variable scope (pr #59)
  * Fix typo in Changelog
* Sun Apr 28 2024 Michael Vetter <mvetter@suse.com>
- Update to 4.0.0:
  * Add Turkish translation (pr #57)
  * Add undo feature (pr #58)
* Thu Dec 21 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.0.0:
  * Fix build failure with ncurses 6.3
  * Add call to PKG_PROG_PKG_CONFIG and pkg-check ncurses libs #46
  * Fix build with musl
  * Add highlighting of user input #56
  * Fix toggling marks removing solution #51
* Fri Nov 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.1.0:
  * Use actual terminal background color (instead of black) as
    background color (pr #31)
  * Define minimum gettext version instead of exact one (pr #32)
  * Require gettext 0.20
  * Add Japanese translation (pr #40)
  * Minor code change
- Drop nudoku-2.0.0-unused-var.patch: upstreamed
- Drop nudoku-2.0.0-gettext.patch: upstreamed
* Thu Feb  6 2020 Michael Vetter <mvetter@suse.com>
- Add nudoku-2.0.0-unused-var.patch:
  Remove unused variable. Fixes build on TW.
- Add nudoku-2.0.0-gettext.patch:
  Require gettext 0.20
* Tue Jul 30 2019 mvetter@suse.com
- Add cairo dependency: enable PDF and PNG creation
* Tue Jul 30 2019 mvetter@suse.com
- Update to 2.0.0:
  * Translation support
  * Added translations for: Spanish, German, Russian
  * Refactoring and code cleanup
  * Add color difference between provided numbers and the ones
    entered by the user
  * Output sudoku PDFs (-p/-n option)
  * Output sudoku PNG (-i option)
  * Fix duplicate fields in sudoku generation (pr #28)
* Thu Apr 19 2018 mvetter@suse.com
- Update to 1.0.0:
  * Add 'mark' command to highlight the currently selected number
    in all other cells. Thanks to James Warnock.
  * Redesign commands display.
  * Display how many hints a person used when the puzzle is solved.
  * Update maintainer email and man page.
  * Code cleanup
* Mon Jun 13 2016 mvetter@suse.com
- Update to version 0.2.5
  * manpage fixes
* Wed Aug 26 2015 mvetter@suse.com
- Version bump to 0.2.4
  * Fix array out of bound in validity_check
* Fri Aug 21 2015 mvetter@suse.com
- Version bump to 0.2.3
  * Code cleanup
* Wed Aug 19 2015 mvetter@suse.com
- Change Source to download location
- Update to version 0.2.2
  * Add manpage
  * User can provide sudokus of his own
  * Major code cleanup
  * Provide hints based on the users board
  * Improve feedback for "check" to let the user know if his sudoku is right so far
* Tue Apr  7 2015 g.bluehut@gmail.com
- Add BuildRequires xz to make it work under SLE11 too.
  Going to add it generally since it is needed anyways, so to make
  sure it exists.
* Tue Apr  7 2015 g.bluehut@gmail.com
- Clean up spec
* Wed Mar 25 2015 g.bluehut@gmail.com
- Rename and clean up spec file
